summaryrefslogtreecommitdiff
path: root/protocols/Weather/weather.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'protocols/Weather/weather.cpp')
-rw-r--r--protocols/Weather/weather.cpp8
1 files changed, 2 insertions, 6 deletions
diff --git a/protocols/Weather/weather.cpp b/protocols/Weather/weather.cpp
index d0527b794e..9c6f762683 100644
--- a/protocols/Weather/weather.cpp
+++ b/protocols/Weather/weather.cpp
@@ -81,12 +81,8 @@ extern "C" __declspec(dllexport) const PLUGININFOEX* MirandaPluginInfoEx(DWORD m
return &pluginInfoEx;
}
-// MirandaPluginInterfaces - returns the protocol interface to the core
-static const MUUID interfaces[] = {MIID_PROTOCOL, MIID_LAST};
-extern "C" __declspec(dllexport) const MUUID* MirandaPluginInterfaces(void)
-{
- return interfaces;
-}
+// MirandaInterfaces - returns the protocol interface to the core
+extern "C" __declspec(dllexport) const MUUID MirandaInterfaces[] = {MIID_PROTOCOL, MIID_LAST};
BOOL WINAPI DllMain(HINSTANCE hinstDLL, DWORD fdwReason, LPVOID lpvReserved)
{